# Basic Usage

Import SmfTools:

```
import smftools as smf
```

## Informatics Module Usage

Many use cases for smftools begin here. For most users, the call below will be sufficient to convert any raw SMF dataset to an AnnData object:

```
config_path = "/Path_to_experiment_config.csv"
smf.inform.load_adata(config_path)
```

## Loading AnnData objects created by the informatics module

After creating an AnnData object holding your experiment's SMF data, you can load the AnnData object as so:

```
import anndata as ad
input_adata = "/Path_to_experiment_AnnData.h5ad.gz"
adata = ad.read_h5ad(input_file)
adata.obs_names_make_unique()
```

If you don't have an AnnData object yet, but want to play with the downstream Preprocessing, Tools, and Plotting modules, you can load a pre-loaded SMF dataset.

Currently, you can do this with our lab's in vitro dCas9 binding kinetics dataset generated from a Hia5 SMF dataset generated with direct m6A high accuracy basecalls:

```
adata = smf.datasets.dCas9_kinetics()
adata.obs_names_make_unique()
```

Alternatively, you can do this with our lab's M.CviPI SMF test data in F1-hybrid natural killer cells generated by NEB EMseq conversion followed by canonical basecalling:

```
adata = smf.datasets.Kissiov_and_McKenna_2025()
adata.obs_names_make_unique()
```

## Writing out AnnData objects to save analysis progress

After preprocessing and downstream analysis of the AnnData object, you can save the AnnData object at any step as so:

```
import anndata as ad
import os

output_dir = '/Path_to_output_directory'
output_adata = 'analyzed_adata.h5ad.gz'
final_output = os.path.join(output_dir, output_adata)
adata.write_h5ad(final_output, compression='gzip')
```


## Troubleshooting
For more advanced usage and help troubleshooting, the API and tutorials for each of the modules is still being developed.
However, you can currently learn about the functions contained within the module by calling:

```
smf.inform.__all__
```

This lists the functions within any given module. If you want to see the associated docstring for a given function, here is an example:

```
print(smf.inform.load_adata.__doc__)
```

These docstrings will provide a brief description of the function and also tell you the input parameters and what the function returns.
In some cases, usage examples will also be provided in the docstring in the form of doctests.